/***************************************************************************
*	Copyright (C) 2004 by karye												*
*	karye@users.sourceforge.net												*
*																			*
*	This program is free software; you can redistribute it and/or modify	*
*	it under the terms of the GNU General Public License as published by	*
*	the Free Software Foundation; either version 2 of the License, or		*
*	(at your option) any later version.										*
*																			*
*	This program is distributed in the hope that it will be useful,			*
*	but WITHOUT ANY WARRANTY; without even the implied warranty of			*
*	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the			*
*	GNU General Public License for more details.							*
*																			*
*	You should have received a copy of the GNU General Public License		*
*	along with this program; if not, write to the							*
*	Free Software Foundation, Inc.,											*
*	59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.				*
***************************************************************************/

#include <klocalizedstring.h>  // for i18n
#include <qdatetime.h>         // for QTime

#include "core/global.h"
#include "global.h"            // for formatTime, parsePackage

inline static const QRegularExpression rxNameVersion = QRegularExpression(QStringLiteral("(?:[a-zA-Z0-9]|-)*"
				"("
				"(-(?:\\d+\\.)*\\d+[a-z]?)"
				"(?:_(?=alpha|beta|pre|rc|p)\\d*)?"
				"(?:-r\\d*)?"
				")") );
/**
* Parse out category, package name and version parts from package.
* @param sring to parse out cpv from
*/
auto parsePackage( const QString& packageString ) -> const QStringList
{
	QStringList list;
	QString nameVersion;
	QString package( packageString );
	package.remove( u' ' );

	// Parse out the category first
	if ( package.contains( u'/' ) ) {
		list << package.section( u'/', 0, 0 );
		nameVersion = package.section( u'/', 1, 1 );
	} else {
		list << QString();
		nameVersion = package;
	}

	// Now package name and version
	QRegularExpressionMatch match = rxNameVersion.match( nameVersion );
	if ( match.hasMatch() ) {
		//Group 1 is version with preceeding '-' so this will pull everything before
		QString name = nameVersion.section( match.captured( 1 ), 0, 0 );
		list << name;
		//then everything after name and '-', should be whatever is in the version
		list << nameVersion.section( name + u'-', 1 );
		return list;
	}
	return QStringList();;
}

/**
* Return duration in seconds formated as "d hh.mm.ss".
*/
auto formatTime( long duration ) -> const QString
{
	QString totalDays;
	long durationDays = 0, totalSeconds = 0;

	durationDays = duration / 86400;
	totalSeconds = duration % 86400;

	if ( durationDays > 0 ) {
		totalDays = i18n( "%1d ", QString::number( durationDays ) );
	}

	QTime emergeTime( 0, 0, 0 );
	emergeTime = emergeTime.addSecs( totalSeconds );
	return totalDays + emergeTime.toString();
}
